﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace TicketSystem.TicketProcessor
{
    public class Ticket
    {
        public int TicketId { get; set; }
        public int TableNumber { get; set; }
        public int ServerId { get; set; }
        public List<Order> Orders { get; set; }
        public DateTime Timestamp { get; set; }
    }

    public class Order
    {
        public MenuCategory Category { get; set; }
        public int MenuId { get; set; }
        public string ItemDescription { get; set; }
    }

    public enum MenuCategory
    {
        Others = -1,

        Appetizer = 0,

        MainCourse = 1,

        Dessert = 2
    }

    public class TicketProcessor
    {
        private readonly Queue<Ticket> _queuedTickets = new Queue<Ticket>();

        public TicketProcessor()
        {
            List<string> apps = new List<string>
            {
                "Mac and Cheese", "Pretzels", "Sweet Potato Fries"
            };

            List<string> mainCourses = new List<string>
            {
                "Steak Burger", "Spaghetti with Meatballs", "Beef Stew"
            };

            List<string> desserts = new List<string>
            {
                "Keylime Pie", "Chocolate Cake", "Ice Cream"
            };

            int menuId = 0;

            //Add some sample data
            for (int i = 0; i < 3; ++i)
            {
                _queuedTickets.Enqueue(new Ticket
                {
                    ServerId = i + 1,
                    TableNumber = i + 1,
                    TicketId = i + 1,
                    Timestamp = DateTime.Now,
                    Orders = new List<Order>
                    {
                        new Order 
                        { 
                            Category = MenuCategory.Appetizer,
                            MenuId = ++menuId,
                            ItemDescription = apps[i]
                        },
                        new Order 
                        { 
                            Category = MenuCategory.MainCourse, 
                            MenuId = ++menuId,
                            ItemDescription = mainCourses[i]
                        },
                        new Order 
                        { 
                            Category = MenuCategory.Dessert,
                            MenuId = ++menuId,
                            ItemDescription = desserts[i]
                        }
                    }
                });
            }
        }

        public List<Ticket> GetTicketsInQueue()
        {
            return _queuedTickets.ToList();
        }

        public void QueueTicket(Ticket ticket)
        {
            _queuedTickets.Enqueue(ticket);
        }

        public Ticket PullTicket()
        {
            return _queuedTickets.Dequeue();
        }
    }
}
